@@ -2,17 +2,21 @@
 #
 # Project    : ipv6calc/lib
 # File       : create_ieee_oui_headerfile.pl
-# Version    : $Id: create_ieee_oui_headerfile.pl,v 1.3 2002/04/05 18:47:22 peter Exp $
+# Version    : $Id: create_ieee_oui_headerfile.pl,v 1.6 2002/07/17 20:41:48 peter Exp $
 # Copyright  : 2002 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Creates a header file out of IEEE/oui.txt
 
 use strict;
 
-my $INFILE = "oui.txt";
+my $INFILE;
 
 my $OUTFILE = "dbieee_oui.h";
 
+$INFILE = shift;
+
+if (! defined $INFILE) { $INFILE = "oui.txt" };
+
 print "Create dbieee_oui.h automatically\n";
 
 open(IN, "<$INFILE") || die "Cannot open infile: $INFILE";
@@ -65,7 +69,7 @@ while (<IN>) {
 		my $oui = uc($t3);
 
 		# replace '(' ')' '&'
-		$oui =~ s/[\(\)\&\']/ /ig;
+		$oui =~ s/[\(\)\&\',]/ /ig;
 
 		# remove unimportand information
 		$oui =~ s/\bINC[\.]*\b//ig;
@@ -80,7 +84,10 @@ while (<IN>) {
 		$oui =~ s/\bAG\b/ELECTRONIC/ig;
 		$oui =~ s/\bKG\b//ig;
 		$oui =~ s/\bBV\b//ig;
-		$oui =~ s/\bINT'L\b/INTERNATIONAL/ig;
+
+		# Replace some text
+		$oui =~ s/\b3 Com\b/3COM/ig;
+		$oui =~ s/\b3Com Europe\b/3COM/ig;
 		$oui =~ s/\bCOMMUNICATIONS\b/COMMUNICATION/ig;
 		$oui =~ s/\bCORPOTATION\b/CORPORATION/ig;
 		$oui =~ s/\bINTERNAIONAL\b/INTERNATIONAL/ig;
@@ -93,6 +100,7 @@ while (<IN>) {
 		$oui =~ s/\bENTERPRISE\b//ig;
 		$oui =~ s/\bCORPORATION\b//ig;
 		$oui =~ s/\bELECTRONIC\b//ig;
+		$oui =~ s/\bHF1-06\b//ig;
 
 		# remove ',' '.'
 		$oui =~ s/[,\.;]/ /ig;
@@ -103,6 +111,10 @@ while (<IN>) {
 
 		# convert spaces to '-'
 		$oui =~ s/\s+/-/ig;
+
+		# Some final cleanup
+		$oui =~ s/-INT-L//ig;
+		$oui =~ s/-B-V//ig;
 	
 		#print $oui . "\n";
 	
